searchNodes=[{"doc":"Dynamic Supervisor that distributes processes among nodes in the cluster. Uses process groups (via :pg ) under the hood to maintain cluster-wide state and coordinate work between supervisor processes running in the cluster. Supervisors are organized into independent scopes. When a supervisor receives a request to start a child process via start_child/2 , instead of starting it immediately, it propagates that request via process groups to supervisors running on other nodes. Termination of child processes via terminate_child/2 works in the same way. Each supervisor periodically synchronizes its local state by processing the start and terminate requests, and updates child process information in cluster-wide state. Supervisor processes running on different nodes, but operating within the same scope, form a hash ring. When processing requests to start child processes, supervisors use consistent hashing to determine if they should accept the request or not, guaranteeing that there will be exactly one supervisor accepting the request and actually starting the child process locally. Cluster topology changes, with supervisors being added or removed, are likely to affect the distribution of child processes - some child processes may get rescheduled to supervisors running on different nodes.","ref":"Pogo.DynamicSupervisor.html","title":"Pogo.DynamicSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Pogo.DynamicSupervisor.html#child_spec/1","title":"Pogo.DynamicSupervisor.child_spec/1","type":"function"},{"doc":"Requests a child process to be started under one of the supervisors in the cluster.","ref":"Pogo.DynamicSupervisor.html#start_child/2","title":"Pogo.DynamicSupervisor.start_child/2","type":"function"},{"doc":"Starts local supervisor and joins cluster-wide scoped process group. Options All options accepted by Supervisor.init/2 are also accepted here, except for :strategy which is always :one_for_one . Additionally the following options can be specified. scope - scope to join, supervisors only cooperate with other supervisors operating within the same scope sync_interval - interval in milliseconds, how often the supervisor should synchronize its local state with the cluster by processing requests to start and terminate child processes, defaults to 5_000 children - list of child specifications to automatially start in the cluster Children specified at startup are handled in the same way as children started dynamically. The only difference is that when Pogo.DynamicSupervisor runs under a supervision tree and is restarted, it will automatically restart all these children as well.","ref":"Pogo.DynamicSupervisor.html#start_link/1","title":"Pogo.DynamicSupervisor.start_link/1","type":"function"},{"doc":"Requests a child process running under one of the supervisors in the cluster to be terminated.","ref":"Pogo.DynamicSupervisor.html#terminate_child/2","title":"Pogo.DynamicSupervisor.terminate_child/2","type":"function"},{"doc":"Returns a list with information about locally or globally supervised children.","ref":"Pogo.DynamicSupervisor.html#which_children/2","title":"Pogo.DynamicSupervisor.which_children/2","type":"function"},{"doc":"","ref":"Pogo.DynamicSupervisor.html#t:init_option/0","title":"Pogo.DynamicSupervisor.init_option/0","type":"type"},{"doc":"","ref":"Pogo.DynamicSupervisor.html#t:option/0","title":"Pogo.DynamicSupervisor.option/0","type":"type"},{"doc":"Pogo is a distributed supervisor for clustered Elixir applications. It uses battle-tested distributed named process groups ( :pg ) under the hood to maintain cluster-wide state and coordinate work between local supervisors running on different nodes. Features of distributed supevisor: automatically chooses a node to locally supervise child process a child process running in the cluster can be started or stopped using any local supervisor ensures a child is started only once in the cluster (as long as its child spec is unique) redistibutes children when cluster topology changes","ref":"readme.html","title":"Pogo","type":"extras"},{"doc":"The package can be installed by adding pogo to your list of dependencies in mix.exs : def deps do [ { :pogo , &quot;~&gt; 0.3.0&quot; } ] end","ref":"readme.html#installation","title":"Pogo - Installation","type":"extras"},{"doc":"Full documentation can be found at hexdocs.pm/pogo .","ref":"readme.html#documentation","title":"Pogo - Documentation","type":"extras"},{"doc":"Let's imagine we have an application running on multiple nodes that needs to monitor some external services and we want each of these services to be monitored only once. Start Pogo.DynamicSupervisor under application's supervision tree, locally on each node. All these local supervisors will form a distributed supervisor named MyApp.DistributedSupervisor . defmodule MyApp.Application do use Application @impl true def start ( _type , _args ) do children = [ { Pogo.DynamicSupervisor , [ name : MyApp.DistributedSupervisor , scope : :my_app ] } ] Supervisor . start_link ( children , strategy : :one_for_one ) end end Now request service monitor processes to be started as children of our distributed supervisor. It can be done on any of the nodes or even on all of them, the distributed supervisor will determine which of the local ones will actually start each child. for service_ip &lt;- [ &quot;10.0.0.1&quot; , &quot;10.0.0.2&quot; , &quot;10.0.0.3&quot; ] do Pogo.DynamicSupervisor . start_child ( MyApp.DistributedSupervisor , %{ id : { MyApp.ServiceMonitor , service_ip } , start : { MyApp.ServiceMonitor , :start_link , [ ip : service_ip ] } } ) end We can list locally and globally supervised child processes. Pogo.DynamicSupervisor . which_children ( MyApp.DistributedSupervisor , :local ) # [{MyApp.ServiceMonitor, &quot;10.0.0.2&quot;}, #PID&lt;0.2010.0&gt;, :worker, [MyApp.ServiceMonitor]] Pogo.DynamicSupervisor . which_children ( MyApp.DistributedSupervisor , :global ) # [ # {MyApp.ServiceMonitor, &quot;10.0.0.2&quot;}, #PID&lt;0.2010.0&gt;, :worker, [MyApp.ServiceMonitor], # {MyApp.ServiceMonitor, &quot;10.0.0.1&quot;}, #PID&lt;4461.199.10&gt;, :worker, [MyApp.ServiceMonitor], # {MyApp.ServiceMonitor, &quot;10.0.0.3&quot;}, #PID&lt;306.320.94&gt;, :worker, [MyApp.ServiceMonitor] # ] To request a child to be terminated, its id needs to be provided. The request can be made on any of the nodes irrespective of whether the child is supervised locally or not. Pogo.DynamicSupervisor . terminate_child ( MyApp.DistributedSupervisor , { MyApp.ServiceMonitor , &quot;10.0.0.3&quot; } )","ref":"readme.html#example-usage","title":"Pogo - Example usage","type":"extras"},{"doc":"Original version of this library was developed by Guilherme Balena Versiani .","ref":"readme.html#acknowledgments","title":"Pogo - Acknowledgments","type":"extras"},{"doc":"GNU Lesser General Public License v3.0, see LICENSE for details.","ref":"readme.html#license","title":"Pogo - License","type":"extras"},{"doc":"GNU LESSER GENERAL PUBLIC LICENSE Version 3, 29 June 2007 Copyright (C) 2007 Free Software Foundation, Inc. &lt;https://fsf.org/&gt; Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed. This version of the GNU Lesser General Public License incorporates the terms and conditions of version 3 of the GNU General Public License, supplemented by the additional permissions listed below. 0. Additional Definitions. As used herein, &quot;this License&quot; refers to version 3 of the GNU Lesser General Public License, and the &quot;GNU GPL&quot; refers to version 3 of the GNU General Public License. &quot;The Library&quot; refers to a covered work governed by this License, other than an Application or a Combined Work as defined below. An &quot;Application&quot; is any work that makes use of an interface provided by the Library, but which is not otherwise based on the Library. Defining a subclass of a class defined by the Library is deemed a mode of using an interface provided by the Library. A &quot;Combined Work&quot; is a work produced by combining or linking an Application with the Library. The particular version of the Library with which the Combined Work was made is also called the &quot;Linked Version&quot;. The &quot;Minimal Corresponding Source&quot; for a Combined Work means the Corresponding Source for the Combined Work, excluding any source code for portions of the Combined Work that, considered in isolation, are based on the Application, and not on the Linked Version. The &quot;Corresponding Application Code&quot; for a Combined Work means the object code and/or source code for the Application, including any data and utility programs needed for reproducing the Combined Work from the Application, but excluding the System Libraries of the Combined Work. 1. Exception to Section 3 of the GNU GPL. You may convey a covered work under sections 3 and 4 of this License without being bound by section 3 of the GNU GPL. 2. Conveying Modified Versions. If you modify a copy of the Library, and, in your modifications, a facility refers to a function or data to be supplied by an Application that uses the facility (other than as an argument passed when the facility is invoked), then you may convey a copy of the modified version: a) under this License, provided that you make a good faith effort to ensure that, in the event an Application does not supply the function or data, the facility still operates, and performs whatever part of its purpose remains meaningful, or b) under the GNU GPL, with none of the additional permissions of this License applicable to that copy. 3. Object Code Incorporating Material from Library Header Files. The object code form of an Application may incorporate material from a header file that is part of the Library. You may convey such object code under terms of your choice, provided that, if the incorporated material is not limited to numerical parameters, data structure layouts and accessors, or small macros, inline functions and templates (ten or fewer lines in length), you do both of the following: a) Give prominent notice with each copy of the object code that the Library is used in it and that the Library and its use are covered by this License. b) Accompany the object code with a copy of the GNU GPL and this license document. 4. Combined Works. You may convey a Combined Work under terms of your choice that, taken together, effectively do not restrict modification of the portions of the Library contained in the Combined Work and reverse engineering for debugging such modifications, if you also do each of the following: a) Give prominent notice with each copy of the Combined Work that the Library is used in it and that the Library and its use are covered by this License. b) Accompany the Combined Work with a copy of the GNU GPL and this license document. c) For a Combined Work that displays copyright notices during execution, include the copyright notice for the Library among these notices, as well as a reference directing the user to the copies of the GNU GPL and this license document. d) Do one of the following: 0) Convey the Minimal Corresponding Source under the terms of this License, and the Corresponding Application Code in a form suitable for, and under terms that permit, the user to recombine or relink the Application with a modified version of the Linked Version to produce a modified Combined Work, in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source. 1) Use a suitable shared library mechanism for linking with the Library. A suitable mechanism is one that (a) uses at run time a copy of the Library already present on the user's computer system, and (b) will operate properly with a modified version of the Library that is interface-compatible with the Linked Version. e) Provide Installation Information, but only if you would otherwise be required to provide such information under section 6 of the GNU GPL, and only to the extent that such information is necessary to install and execute a modified version of the Combined Work produced by recombining or relinking the Application with a modified version of the Linked Version. (If you use option 4d0, the Installation Information must accompany the Minimal Corresponding Source and Corresponding Application Code. If you use option 4d1, you must provide the Installation Information in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.) 5. Combined Libraries. You may place library facilities that are a work based on the Library side by side in a single library together with other library facilities that are not Applications and are not covered by this License, and convey such a combined library under terms of your choice, if you do both of the following: a) Accompany the combined library with a copy of the same work based on the Library, uncombined with any other library facilities, conveyed under the terms of this License. b) Give prominent notice with the combined library that part of it is a work based on the Library, and explaining where to find the accompanying uncombined form of the same work. 6. Revised Versions of the GNU Lesser General Public License. The Free Software Foundation may publish revised and/or new versions of the GNU Lesser General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns. Each version is given a distinguishing version number. If the Library as you received it specifies that a certain numbered version of the GNU Lesser General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that published version or of any later version published by the Free Software Foundation. If the Library as you received it does not specify a version number of the GNU Lesser General Public License, you may choose any version of the GNU Lesser General Public License ever published by the Free Software Foundation. If the Library as you received it specifies that a proxy can decide whether future versions of the GNU Lesser General Public License shall apply, that proxy's public statement of acceptance of any version is permanent authorization for you to choose that version for the Library.","ref":"license.html","title":"LICENSE","type":"extras"}]